
# Type: overlaps


holds between entties that overlap in their extents (materials or processes)

URI: [biolink:overlaps](https://w3id.org/biolink/vocab/overlaps)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [has part](has_part.md)
 *  [part of](part_of.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002131 |
| **In Subsets:** | | translator_minimal |

